import { ValidationsInfo, HostRole } from '../../common/types/hosts';
import { Cluster, ClusterValidationId, DiskRole, Event, HostValidationId } from '../api';
import { ValidationGroup as ClusterValidationGroup } from '../types/clusters';
export declare const OPENSHIFT_LIFE_CYCLE_DATES_LINK = "https://access.redhat.com/support/policy/updates/openshift#dates";
export declare const OPENSHIFT_NETWORKING_DOCS_LINK = "https://docs.openshift.com/container-platform/4.7/installing/installing_bare_metal/installing-bare-metal.html#installation-network-user-infra_installing-bare-metal";
export declare const CLUSTER_MANAGER_SITE_LINK = "https://console.redhat.com/openshift/install/pull-secret";
export declare const PULL_SECRET_INFO_LINK = "https://console.redhat.com/openshift/install/pull-secret";
export declare const ODF_REQUIREMENTS_LINK = "https://access.redhat.com/documentation/en-us/red_hat_openshift_data_foundation/4.9/html/planning_your_deployment/infrastructure-requirements_rhodf#resource-requirements_rhodf";
export declare const VSPHERE_CONFIG_LINK = "https://access.redhat.com/solutions/6677901";
export declare const getBugzillaLink: (version?: string) => string;
export declare const FEEDBACK_FORM_LINK = "https://docs.google.com/forms/d/e/1FAIpQLSfg9M8wRW4m_HkWeAl6KpB5dTcMu8iI3iJ29GlLfZpF2hnjng/viewform";
export declare const TECH_SUPPORT_LEVEL_LINK = "https://access.redhat.com/support/offerings/techpreview";
export declare const ENCRYPTING_DISK_DURING_INSTALLATION = "https://docs.openshift.com/container-platform/4.7/installing/install_config/installing-customizing.html#installation-special-config-encrypt-disk_installing-customizing";
export declare const getOcpConsoleNodesPage: (ocpConsoleUrl: string) => string;
export declare const REDHAT_CONSOLE_OPENSHIFT = "https://console.redhat.com/openshift";
export declare const SSH_GENERATION_DOC_LINK = "https://www.redhat.com/sysadmin/configure-ssh-keygen";
export declare const getProductBrandingCode: () => string;
export declare const POLLING_INTERVAL: number;
export declare const EVENTS_POLLING_INTERVAL: number;
export declare const hostRoles: (t: any) => HostRole[];
export declare const clusterStatusLabels: (t: any) => {
    insufficient: string;
    ready: string;
    error: string;
    "preparing-for-installation": string;
    "pending-for-input": string;
    installing: string;
    finalizing: string;
    installed: string;
    "adding-hosts": string;
    cancelled: string;
    "installing-pending-user-action": string;
};
export declare const clusterFieldLabels: (t: any) => {
    [x: string]: string;
};
export declare const hostValidationGroupLabels: (t: any) => {
    hardware?: string | undefined;
    network?: string | undefined;
    operators?: string | undefined;
    infrastructure?: string | undefined;
};
export declare const hostValidationLabels: (t: any) => {
    connected: string;
    "media-connected": string;
    "has-inventory": string;
    "has-min-cpu-cores": string;
    "has-min-valid-disks": string;
    "has-min-memory": string;
    "machine-cidr-defined": string;
    "has-cpu-cores-for-role": string;
    "has-memory-for-role": string;
    "hostname-unique": string;
    "hostname-valid": string;
    "belongs-to-machine-cidr": string;
    "ignition-downloadable": string;
    "belongs-to-majority-group": string;
    "valid-platform-network-settings": string;
    "ntp-synced": string;
    "container-images-available": string;
    "lso-requirements-satisfied": string;
    "ocs-requirements-satisfied": string;
    "odf-requirements-satisfied": string;
    "sufficient-installation-disk-speed": string;
    "cnv-requirements-satisfied": string;
    "sufficient-network-latency-requirement-for-role": string;
    "sufficient-packet-loss-requirement-for-role": string;
    "has-default-route": string;
    "api-domain-name-resolved-correctly": string;
    "api-int-domain-name-resolved-correctly": string;
    "apps-domain-name-resolved-correctly": string;
    "compatible-with-cluster-platform": string;
    "dns-wildcard-not-configured": string;
    "disk-encryption-requirements-satisfied": string;
    "non-overlapping-subnets": string;
    "vsphere-disk-uuid-enabled": string;
    "compatible-agent": string;
};
export declare const hostValidationFailureHints: (t: any) => {
    connected: string;
    "media-connected": string;
    "has-inventory": string;
    "has-min-cpu-cores": string;
    "has-min-valid-disks": string;
    "has-min-memory": string;
    "machine-cidr-defined": string;
    "has-cpu-cores-for-role": string;
    "has-memory-for-role": string;
    "hostname-unique": string;
    "hostname-valid": string;
    "belongs-to-machine-cidr": string;
    "ignition-downloadable": string;
    "belongs-to-majority-group": string;
    "valid-platform-network-settings": string;
    "ntp-synced": string;
    "container-images-available": string;
    "lso-requirements-satisfied": string;
    "ocs-requirements-satisfied": string;
    "odf-requirements-satisfied": string;
    "sufficient-installation-disk-speed": string;
    "cnv-requirements-satisfied": string;
    "sufficient-network-latency-requirement-for-role": string;
    "sufficient-packet-loss-requirement-for-role": string;
    "has-default-route": string;
    "api-domain-name-resolved-correctly": string;
    "api-int-domain-name-resolved-correctly": string;
    "apps-domain-name-resolved-correctly": string;
    "compatible-with-cluster-platform": string;
    "dns-wildcard-not-configured": string;
    "disk-encryption-requirements-satisfied": string;
    "non-overlapping-subnets": string;
    "vsphere-disk-uuid-enabled": string;
    "compatible-agent": string;
};
export declare const clusterValidationLabels: (t: any) => {
    "machine-cidr-defined": string;
    "lso-requirements-satisfied": string;
    "ocs-requirements-satisfied": string;
    "odf-requirements-satisfied": string;
    "cnv-requirements-satisfied": string;
    "cluster-cidr-defined": string;
    "service-cidr-defined": string;
    "no-cidrs-overlapping": string;
    "networks-same-address-families": string;
    "network-prefix-valid": string;
    "machine-cidr-equals-to-calculated-cidr": string;
    "api-vip-defined": string;
    "api-vip-valid": string;
    "ingress-vip-defined": string;
    "ingress-vip-valid": string;
    "all-hosts-are-ready-to-install": string;
    "sufficient-masters-count": string;
    "dns-domain-defined": string;
    "pull-secret-set": string;
    "ntp-server-configured": string;
    "network-type-valid": string;
};
export declare const clusterValidationGroupLabels: (t: any) => {
    network: string;
    operators: string;
    configuration: string;
    hostsData: string;
    "hosts-data": string;
};
export declare const CLUSTER_DEFAULT_NETWORK_SETTINGS_IPV4: {
    clusterNetworkCidr: string;
    clusterNetworkHostPrefix: number;
    serviceNetworkCidr: string;
};
export declare const CLUSTER_DEFAULT_NETWORK_SETTINGS_IPV6: {
    clusterNetworkCidr: string;
    clusterNetworkHostPrefix: number;
    serviceNetworkCidr: string;
};
export declare const getAssistedUiLibVersion: () => string;
export declare const EVENT_SEVERITIES: Event['severity'][];
export declare const TIME_ZERO = "0001-01-01T00:00:00.000Z";
export declare const MS_PER_DAY: number;
export declare const NO_SUBNET_SET = "NO_SUBNET_SET";
export declare const NETWORK_TYPE_OVN = "OVNKubernetes";
export declare const NETWORK_TYPE_SDN = "OpenShiftSDN";
export declare const IPV4_STACK = "singleStack";
export declare const DUAL_STACK = "dualStack";
export declare const PREFIX_MAX_RESTRICTION: {
    IPv6: number;
    IPv4: number;
};
export declare const diskRoleLabels: (t: any) => {
    none: string;
    install: string;
};
export declare const SNO_SUPPORT_MIN_VERSION = 4.8;
export declare const OPERATOR_NAME_CNV = "cnv";
export declare const OPERATOR_NAME_LSO = "lso";
export declare const OPERATOR_NAME_OCS = "ocs";
export declare const OPERATOR_NAME_ODF = "odf";
export declare const OPERATOR_NAME_CVO = "cvo";
export declare const OPERATOR_NAME_CONSOLE = "console";
export declare const operatorLabels: (t: any) => {
    console: any;
    cvo: any;
    lso: any;
    ocs: any;
    odf: any;
    cnv: any;
};
export declare const OCP_STATIC_IP_DOC = "https://docs.openshift.com/container-platform/latest/scalability_and_performance/ztp-deploying-disconnected.html#ztp-configuring-a-static-ip_ztp-deploying-disconnected";
