import { ProtocolVersion } from './dataTypes';
export declare enum NmstateInterfaceType {
    ETHERNET = "ethernet",
    VLAN = "vlan"
}
export declare type NmstateAddress = {
    ip: string;
    'prefix-length': number;
};
export declare type NmstateProtocolConfig = {
    address: NmstateAddress[];
    enabled: boolean;
    dhcp: boolean;
};
export declare type NmstateProtocolConfigs = {
    [protocolVersion in ProtocolVersion]?: NmstateProtocolConfig;
};
export declare type NmstateEthernetInterface = {
    name: string;
    type: NmstateInterfaceType.ETHERNET;
    state: string;
} & NmstateProtocolConfigs;
export declare type NmstateRoutesConfig = {
    destination: string;
    'next-hop-address': string;
    'next-hop-interface': string;
    'table-id': number;
};
export declare type NmstateRoutes = {
    config: NmstateRoutesConfig[];
};
export declare type NmstateDns = {
    config: {
        server: string[];
    };
};
export declare type NmstateVlanInterface = {
    name: string;
    type: NmstateInterfaceType.VLAN;
    state: string;
    vlan: {
        'base-iface': string;
        id: number;
    };
} & NmstateProtocolConfigs;
export declare type NmstateInterface = NmstateEthernetInterface | NmstateVlanInterface;
export declare const isVlanInterface: (nmStateInterface: NmstateVlanInterface | NmstateEthernetInterface) => nmStateInterface is NmstateVlanInterface;
export declare const isEthernetInterface: (nmStateInterface: NmstateVlanInterface | NmstateEthernetInterface) => nmStateInterface is NmstateEthernetInterface;
export declare type Nmstate = {
    'dns-resolver'?: NmstateDns;
    routes?: {
        config: {
            destination: string;
            'next-hop-address': string;
            'next-hop-interface': string;
            'table-id': number;
        }[];
    };
    interfaces: NmstateInterface[];
};
